@@ -33,13 +33,8 @@ int main(int argc, char *argv[])
 
     viewer.setMainQmlFile(QLatin1String("/opt/lichvietwidget/qml/lichvietwidget/main.qml"));
 
-    /*
-    viewer.setFixedWidth(390);
-    viewer.setFixedHeight(340);
-    */
-
     QMaemo5HomescreenAdaptor *adaptor = new QMaemo5HomescreenAdaptor(&viewer);
-    adaptor->setSettingsAvailable(false);//true for menu widget dialog
+    adaptor->setSettingsAvailable(false);
 
     SettingsDlg settingsdlg;
 
