@@ -20,7 +20,7 @@ var isday=-1;
 var ismonth=-1;
 var isyear=-1;
 
-function refresh(day_center_img, day_left_img, day_right_img, month_left_img, month_right_img, year_1_img, year_2_img,year_3_img,year_4_img, txt_detail) {
+function refresh(day_center_img, day_left_img, day_right_img, month_left_img, month_right_img, year_1_img, year_2_img,year_3_img,year_4_img, txt_detail, txt_thu) {
     var date = new Date();
 
     var lunar = getLunarDate(date.getDate(),date.getMonth()+1,date.getFullYear());
@@ -29,6 +29,8 @@ function refresh(day_center_img, day_left_img, day_right_img, month_left_img, mo
     var xmonth = lunar.month;
     var xyear = lunar.year;
 
+    txt_thu.text = getTHU(lunar.jd);
+
     txt_detail.text = "Ngày <b>"+lunarCanChi[0]+"</b>, Tháng <b>"+lunarCanChi[1]+"</b><br>Năm <b>"+lunarCanChi[2]+"</b>";
 
     if (xday != isday){
